MODULE Mui;

IMPORT Exec, Utility, Intuition, SYSTEM, ASL;

CONST
  LibName* = "muimaster.library";
  Version* = 4;


TYPE
  Object * = Intuition.ObjectPtr;


(***************************************************************************
**
** For Boopsi Image Implementors Only:
**
** If MUI is using a boopsi image object, it will send a special method
** immediately after object creation. This method has a parameter structure
** where the boopsi can fill in its minimum and maximum size and learn if
** its used in a horizontal or vertical context.
**
** The boopsi image must use the method id (MUIM_BoopsiQuery) as return
** value. That's how MUI sees that the method is implemented.
**
** Note: MUI does not depend on this method. If the boopsi image doesn't
**       implement it, minimum size will be 0 and maximum size unlimited.
**
***************************************************************************)

CONST mBoopsiQuery *= 80427157H;    (* this is send to the boopsi and *)
                                    (* must be used as return value   *)

TYPE pBoopsiQuery  *= STRUCT( msg* : Intuition.Msg ); (* parameter structure *)

                  screen    * : Intuition.ScreenPtr;  (* read only, display context *)
                  flags     * : LONGSET;              (* read only, see below *)

                  minWidth  * : LONGINT;              (* write only, fill in min width  *)
                  minHeight * : LONGINT;              (* write only, fill in min height *)
                  maxWidth  * : LONGINT;              (* write only, fill in max width  *)
                  maxHeight * : LONGINT;              (* write only, fill in max height *)

                  (* may grow in future ... *)
                  END;

CONST bqfHoriz *= 0;             (* object used in a horizontal *)
                                 (* context (else vertical)     *)

CONST bqMaxMax *= 10000;         (* use this for unlimited MaxWidth/Height *)


(***************************************************************************
** ARexx Interface
***************************************************************************)

TYPE
  Command * = STRUCT
    name            * : Exec.STRPTR;
    template        * : Exec.STRPTR;
    parameters      * : LONGINT;
    hook            * : Utility.HookPtr;
    reserved        * : ARRAY 5 OF LONGINT;
  END;


(***************************************************************************
** Return values for MUI_Error()
***************************************************************************)

CONST

        eOK                  * = 0;
        eOutOfMemory         * = 1;
        eOutOfGfxMemory      * = 2;
        eInvalidWindowObject * = 3;
        eMissingLibrary      * = 4;
        eNoARexx             * = 5;
        eSingleTask          * = 6;


(***************************************************************************
** Standard MUI Images
***************************************************************************)

CONST
        iWindowBack    * =  0;
        iRequesterBack * =  1;
        iButtonBack    * =  2;
        iListBack      * =  3;
        iTextBack      * =  4;
        iPropBack      * =  5;
        iActiveBack    * =  6;
        iSelectedBack  * =  7;
        iListCursor    * =  8;
        iListSelect    * =  9;
        iListSelCur    * = 10;
        iArrowUp       * = 11;
        iArrowDown     * = 12;
        iArrowLeft     * = 13;
        iArrowRight    * = 14;
        iCheckMark     * = 15;
        iRadioButton   * = 16;
        iCycle         * = 17;
        iPopUp         * = 18;
        iPopFile       * = 19;
        iPopDrawer     * = 20;
        iPropKnob      * = 21;
        iDrawer        * = 22;
        iHardDisk      * = 23;
        iDisk          * = 24;
        iChip          * = 25;
        iVolume        * = 26;
        iCount         * = 27;

        iBACKGROUND  * = (128+ 0);
        iSHADOW      * = (128+ 1);
        iSHINE       * = (128+ 2);
        iFILL        * = (128+ 3);
        iSHADOWBACK  * = (128+ 4);
        iSHADOWFILL  * = (128+ 5);
        iSHADOWSHINE * = (128+ 6);
        iFILLBACK    * = (128+ 7);
        iFILLSHINE   * = (128+ 8);
        iSHINEBACK   * = (128+ 9);
        iFILLBACK2   * = (128+10);


(***************************************************************************
** Special values for some methods
***************************************************************************)

CONST

        vTriggerValue *= 49893131H;
        vEveryTime    *= 49893131H;

        vApplicationSaveENV     * =  0;
        vApplicationSaveENVARC  * = -1;
        vApplicationLoadENV     * =  0;
        vApplicationLoadENVARC  * = -1;

        vApplicationReturnIDQuit * = -1;

        vListInsertTop       * =  0;
        vListInsertActive    * = -1;
        vListInsertSorted    * = -2;
        vListInsertBottom    * = -3;

        vListRemoveFirst     * =  0;
        vListRemoveActive    * = -1;
        vListRemoveLast      * = -2;

        vListSelectOff       * =  0;
        vListSelectOn        * =  1;
        vListSelectToggle    * =  2;
        vListSelectAsk       * =  3;

        vListJumpActive      * = -1;
        vListGetEntryActive  * = -1;
        vListSelectActive    * = -1;

        vListRedrawActive    * = -1;
        vListRedrawAll       * = -2;

        vListExchangeActive  * = -1;


(****************************************************************************)
(** Notify.mui 6.65 (26.10.93)                                             **)
(****************************************************************************)

  cNotify * = "Notify.mui";

(* Methods *)

  CONST mCallHook                  * = 8042B96BH;
  CONST mNotify                    * = 8042C9CBH;
  CONST mSet                       * = 8042549AH;
  CONST mSetAsString               * = 80422590H;
  CONST mWriteLong                 * = 80428D86H;
  CONST mWriteString               * = 80424BF4H;

(* Attributes *)

  CONST aAppMessage                 * = 80421955H; (* ..g struct AppMessage * *)
  CONST aHelpFile                   * = 80423A6EH; (* isg STRPTR            *)
  CONST aHelpLine                   * = 8042A825H; (* isg LONG              *)
  CONST aHelpNode                   * = 80420B85H; (* isg STRPTR            *)
  CONST aRevision                   * = 80427EAAH; (* ..g LONG              *)
  CONST aUserData                   * = 80420313H; (* isg ULONG             *)
  CONST aVersion                    * = 80422301H; (* ..g LONG              *)



(****************************************************************************)
(** Application.mui 6.57 (26.10.93)                                        **)
(****************************************************************************)

  cApplication * = "Application.mui";

(* Methods *)

  CONST mApplicationGetMenuCheck   * = 8042C0A7H;
  CONST mApplicationGetMenuState   * = 8042A58FH;
  CONST mApplicationInput          * = 8042D0F5H;
  CONST mApplicationInputBuffered  * = 80427E59H;
  CONST mApplicationLoad           * = 8042F90DH;
  CONST mApplicationPushMethod     * = 80429EF8H;
  CONST mApplicationReturnID       * = 804276EFH;
  CONST mApplicationSave           * = 804227EFH;
  CONST mApplicationSetMenuCheck   * = 8042A707H;
  CONST mApplicationSetMenuState   * = 80428BEFH;
  CONST mApplicationShowHelp       * = 80426479H;

(* Attributes *)

  CONST aApplicationActive          * = 804260ABH; (* isg BOOL              *)
  CONST aApplicationAuthor          * = 80424842H; (* i.g STRPTR            *)
  CONST aApplicationBase            * = 8042E07AH; (* i.g STRPTR            *)
  CONST aApplicationBroker          * = 8042DBCEH; (* ..g Broker *          *)
  CONST aApplicationBrokerHook      * = 80428F4BH; (* isg struct Hook *     *)
  CONST aApplicationBrokerPort      * = 8042E0ADH; (* ..g struct MsgPort *  *)
  CONST aApplicationBrokerPri       * = 8042C8D0H; (* i.g LONG              *)
  CONST aApplicationCommands        * = 80428648H; (* isg struct MUI_Command * *)
  CONST aApplicationCopyright       * = 8042EF4DH; (* i.g STRPTR            *)
  CONST aApplicationDescription     * = 80421FC6H; (* i.g STRPTR            *)
  CONST aApplicationDiskObject      * = 804235CBH; (* isg struct DiskObject * *)
  CONST aApplicationDoubleStart     * = 80423BC6H; (* ..g BOOL              *)
  CONST aApplicationDropObject      * = 80421266H; (* is. Object *          *)
  CONST aApplicationIconified       * = 8042A07FH; (* .sg BOOL              *)
  CONST aApplicationMenu            * = 80420E1FH; (* i.g struct NewMenu *  *)
  CONST aApplicationMenuAction      * = 80428961H; (* ..g ULONG             *)
  CONST aApplicationMenuHelp        * = 8042540BH; (* ..g ULONG             *)
  CONST aApplicationRexxMsg         * = 8042FD88H; (* ..g struct RxMsg *    *)
  CONST aApplicationRexxString      * = 8042D711H; (* .s. STRPTR            *)
  CONST aApplicationSingleTask      * = 8042A2C8H; (* i.. BOOL              *)
  CONST aApplicationSleep           * = 80425711H; (* .s. BOOL              *)
  CONST aApplicationTitle           * = 804281B8H; (* i.g STRPTR            *)
  CONST aApplicationVersion         * = 8042B33FH; (* i.g STRPTR            *)
  CONST aApplicationWindow          * = 8042BFE0H; (* i.. Object *          *)



(****************************************************************************)
(** Window.mui 6.117 (26.10.93)                                            **)
(****************************************************************************)

  cWindow * = "Window.mui";

(* Methods *)

  CONST mWindowGetMenuCheck        * = 80420414H;
  CONST mWindowGetMenuState        * = 80420D2FH;
  CONST mWindowScreenToBack        * = 8042913DH;
  CONST mWindowScreenToFront       * = 804227A4H;
  CONST mWindowSetCycleChain       * = 80426510H;
  CONST mWindowSetMenuCheck        * = 80422243H;
  CONST mWindowSetMenuState        * = 80422B5EH;
  CONST mWindowToBack              * = 8042152EH;
  CONST mWindowToFront             * = 8042554FH;

(* Attributes *)

  CONST aWindowActivate             * = 80428D2FH; (* isg BOOL              *)
  CONST aWindowActiveObject         * = 80427925H; (* .sg Object *          *)
  CONST aWindowAltHeight            * = 8042CCE3H; (* i.g LONG              *)
  CONST aWindowAltLeftEdge          * = 80422D65H; (* i.g LONG              *)
  CONST aWindowAltTopEdge           * = 8042E99BH; (* i.g LONG              *)
  CONST aWindowAltWidth             * = 804260F4H; (* i.g LONG              *)
  CONST aWindowAppWindow            * = 804280CFH; (* i.. BOOL              *)
  CONST aWindowBackdrop             * = 8042C0BBH; (* i.. BOOL              *)
  CONST aWindowBorderless           * = 80429B79H; (* i.. BOOL              *)
  CONST aWindowCloseGadget          * = 8042A110H; (* i.. BOOL              *)
  CONST aWindowCloseRequest         * = 8042E86EH; (* ..g BOOL              *)
  CONST aWindowDefaultObject        * = 804294D7H; (* isg Object *          *)
  CONST aWindowDepthGadget          * = 80421923H; (* i.. BOOL              *)
  CONST aWindowDragBar              * = 8042045DH; (* i.. BOOL              *)
  CONST aWindowHeight               * = 80425846H; (* i.g LONG              *)
  CONST aWindowID                   * = 804201BDH; (* isg ULONG             *)
  CONST aWindowInputEvent           * = 804247D8H; (* ..g struct InputEvent * *)
  CONST aWindowLeftEdge             * = 80426C65H; (* i.g LONG              *)
  CONST aWindowMenu                 * = 8042DB94H; (* i.. struct NewMenu *  *)
  CONST aWindowNoMenus              * = 80429DF5H; (* .s. BOOL              *)
  CONST aWindowOpen                 * = 80428AA0H; (* .sg BOOL              *)
  CONST aWindowPublicScreen         * = 804278E4H; (* isg STRPTR            *)
  CONST aWindowRefWindow            * = 804201F4H; (* is. Object *          *)
  CONST aWindowRootObject           * = 8042CBA5H; (* i.. Object *          *)
  CONST aWindowScreen               * = 8042DF4FH; (* isg struct Screen *   *)
  CONST aWindowScreenTitle          * = 804234B0H; (* isg STRPTR            *)
  CONST aWindowSizeGadget           * = 8042E33DH; (* i.. BOOL              *)
  CONST aWindowSizeRight            * = 80424780H; (* i.. BOOL              *)
  CONST aWindowSleep                * = 8042E7DBH; (* .sg BOOL              *)
  CONST aWindowTitle                * = 8042AD3DH; (* isg STRPTR            *)
  CONST aWindowTopEdge              * = 80427C66H; (* i.g LONG              *)
  CONST aWindowWidth                * = 8042DCAEH; (* i.g LONG              *)
  CONST aWindowWindow               * = 80426A42H; (* ..g struct Window *   *)

  CONST vWindowActiveObjectNone     * = 0;
  CONST vWindowActiveObjectNext     * = -1;
  CONST vWindowActiveObjectPrev     * = -2;
  PROCEDURE vWindowAltHeightMinMax      * (p:LONGINT): LONGINT; BEGIN RETURN (0-(p)) END vWindowAltHeightMinMax;
  PROCEDURE vWindowAltHeightVisible     * (p:LONGINT): LONGINT; BEGIN RETURN (-100-(p)) END vWindowAltHeightVisible;
  PROCEDURE vWindowAltHeightScreen      * (p:LONGINT): LONGINT; BEGIN RETURN (-200-(p)) END vWindowAltHeightScreen;
  CONST vWindowAltHeightScaled      * = -1000;
  CONST vWindowAltLeftEdgeCentered  * = -1;
  CONST vWindowAltLeftEdgeMoused    * = -2;
  CONST vWindowAltLeftEdgeNoChange  * = -1000;
  CONST vWindowAltTopEdgeCentered   * = -1;
  CONST vWindowAltTopEdgeMoused     * = -2;
  PROCEDURE vWindowAltTopEdgeDelta      * (p:LONGINT): LONGINT; BEGIN RETURN (-3-(p)) END vWindowAltTopEdgeDelta;
  CONST vWindowAltTopEdgeNoChange   * = -1000;
  PROCEDURE vWindowAltWidthMinMax       * (p:LONGINT): LONGINT; BEGIN RETURN (0-(p)) END vWindowAltWidthMinMax;
  PROCEDURE vWindowAltWidthVisible      * (p:LONGINT): LONGINT; BEGIN RETURN (-100-(p)) END vWindowAltWidthVisible;
  PROCEDURE vWindowAltWidthScreen       * (p:LONGINT): LONGINT; BEGIN RETURN (-200-(p)) END vWindowAltWidthScreen;
  CONST vWindowAltWidthScaled       * = -1000;
  PROCEDURE vWindowHeightMinMax         * (p:LONGINT): LONGINT; BEGIN RETURN (0-(p)) END vWindowHeightMinMax;
  PROCEDURE vWindowHeightVisible        * (p:LONGINT): LONGINT; BEGIN RETURN (-100-(p)) END vWindowHeightVisible;
  PROCEDURE vWindowHeightScreen         * (p:LONGINT): LONGINT; BEGIN RETURN (-200-(p)) END vWindowHeightScreen;
  CONST vWindowHeightScaled         * = -1000;
  CONST vWindowHeightDefault        * = -1001;
  CONST vWindowLeftEdgeCentered     * = -1;
  CONST vWindowLeftEdgeMoused       * = -2;
  CONST vWindowMenuNoMenu           * = -1;
  CONST vWindowTopEdgeCentered      * = -1;
  CONST vWindowTopEdgeMoused        * = -2;
  PROCEDURE vWindowTopEdgeDelta         * (p:LONGINT): LONGINT; BEGIN RETURN (-3-(p)) END vWindowTopEdgeDelta;
  PROCEDURE vWindowWidthMinMax          * (p:LONGINT): LONGINT; BEGIN RETURN (0-(p)) END vWindowWidthMinMax;
  PROCEDURE vWindowWidthVisible         * (p:LONGINT): LONGINT; BEGIN RETURN (-100-(p)) END vWindowWidthVisible;
  PROCEDURE vWindowWidthScreen          * (p:LONGINT): LONGINT; BEGIN RETURN (-200-(p)) END vWindowWidthScreen;
  CONST vWindowWidthScaled          * = -1000;
  CONST vWindowWidthDefault         * = -1001;


(****************************************************************************)
(** Area.mui 6.131 (26.10.93)                                              **)
(****************************************************************************)

  cArea * = "Area.mui";

(* Methods *)


(* Attributes *)

  CONST aApplicationObject          * = 8042D3EEH; (* ..g Object *          *)
  CONST aBackground                 * = 8042545BH; (* is. LONG              *)
  CONST aBottomEdge                 * = 8042E552H; (* ..g LONG              *)
  CONST aControlChar                * = 8042120BH; (* i.. char              *)
  CONST aDisabled                   * = 80423661H; (* isg BOOL              *)
  CONST aExportID                   * = 8042D76EH; (* isg LONG              *)
  CONST aFixHeight                  * = 8042A92BH; (* i.. LONG              *)
  CONST aFixHeightTxt               * = 804276F2H; (* i.. LONG              *)
  CONST aFixWidth                   * = 8042A3F1H; (* i.. LONG              *)
  CONST aFixWidthTxt                * = 8042D044H; (* i.. STRPTR            *)
  CONST aFont                       * = 8042BE50H; (* i.g struct TextFont * *)
  CONST aFrame                      * = 8042AC64H; (* i.. LONG              *)
  CONST aFramePhantomHoriz          * = 8042ED76H; (* i.. BOOL              *)
  CONST aFrameTitle                 * = 8042D1C7H; (* i.. STRPTR            *)
  CONST aHeight                     * = 80423237H; (* ..g LONG              *)
  CONST aHorizWeight                * = 80426DB9H; (* i.. LONG              *)
  CONST aInnerBottom                * = 8042F2C0H; (* i.. LONG              *)
  CONST aInnerLeft                  * = 804228F8H; (* i.. LONG              *)
  CONST aInnerRight                 * = 804297FFH; (* i.. LONG              *)
  CONST aInnerTop                   * = 80421EB6H; (* i.. LONG              *)
  CONST aInputMode                  * = 8042FB04H; (* i.. LONG              *)
  CONST aLeftEdge                   * = 8042BEC6H; (* ..g LONG              *)
  CONST aPressed                    * = 80423535H; (* ..g BOOL              *)
  CONST aRightEdge                  * = 8042BA82H; (* ..g LONG              *)
  CONST aSelected                   * = 8042654BH; (* isg BOOL              *)
  CONST aShowSelState               * = 8042CAACH; (* i.. BOOL              *)
  CONST aTimer                      * = 80426435H; (* ..g LONG              *)
  CONST aTopEdge                    * = 8042509BH; (* ..g LONG              *)
  CONST aVertWeight                 * = 804298D0H; (* i.. LONG              *)
  CONST aWeight                     * = 80421D1FH; (* i.. LONG              *)
  CONST aWidth                      * = 8042B59CH; (* ..g LONG              *)
  CONST aWindow                     * = 80421591H; (* ..g struct Window *   *)
  CONST aWindowObject               * = 8042669EH; (* ..g Object *          *)

  CONST vFontInherit                * = 0;
  CONST vFontNormal                 * = -1;
  CONST vFontList                   * = -2;
  CONST vFontTiny                   * = -3;
  CONST vFontFixed                  * = -4;
  CONST vFontTitle                  * = -5;
  CONST vFrameNone                  * = 0;
  CONST vFrameButton                * = 1;
  CONST vFrameImageButton           * = 2;
  CONST vFrameText                  * = 3;
  CONST vFrameString                * = 4;
  CONST vFrameReadList              * = 5;
  CONST vFrameInputList             * = 6;
  CONST vFrameProp                  * = 7;
  CONST vFrameGauge                 * = 8;
  CONST vFrameGroup                 * = 9;
  CONST vFramePopUp                 * = 10;
  CONST vFrameVirtual               * = 11;
  CONST vFrameCount                 * = 12;
  CONST vInputModeNone              * = 0;
  CONST vInputModeRelVerify         * = 1;
  CONST vInputModeImmediate         * = 2;
  CONST vInputModeToggle            * = 3;


(****************************************************************************)
(** Rectangle.mui 6.47 (26.10.93)                                          **)
(****************************************************************************)

  cRectangle * = "Rectangle.mui";


(****************************************************************************)
(** Image.mui 6.61 (26.10.93)                                              **)
(****************************************************************************)

  cImage * = "Image.mui";

(* Attributes *)

  CONST aImageFontMatch             * = 8042815DH; (* i.. BOOL              *)
  CONST aImageFontMatchHeight       * = 80429F26H; (* i.. BOOL              *)
  CONST aImageFontMatchWidth        * = 804239BFH; (* i.. BOOL              *)
  CONST aImageFreeHoriz             * = 8042DA84H; (* i.. BOOL              *)
  CONST aImageFreeVert              * = 8042EA28H; (* i.. BOOL              *)
  CONST aImageOldImage              * = 80424F3DH; (* i.. struct Image *    *)
  CONST aImageSpec                  * = 804233D5H; (* i.. char *            *)
  CONST aImageState                 * = 8042A3ADH; (* is. LONG              *)



(****************************************************************************)
(** Text.mui 6.60 (26.10.93)                                               **)
(****************************************************************************)

  cText * = "Text.mui";

(* Attributes *)

  CONST aTextContents               * = 8042F8DCH; (* isg STRPTR            *)
  CONST aTextHiChar                 * = 804218FFH; (* i.. char              *)
  CONST aTextPreParse               * = 8042566DH; (* isg STRPTR            *)
  CONST aTextSetMax                 * = 80424D0AH; (* i.. BOOL              *)
  CONST aTextSetMin                 * = 80424E10H; (* i.. BOOL              *)



(****************************************************************************)
(** String.mui 6.62 (26.10.93)                                             **)
(****************************************************************************)

  cString * = "String.mui";

(* Attributes *)

  CONST aStringAccept               * = 8042E3E1H; (* isg STRPTR            *)
  CONST aStringAcknowledge          * = 8042026CH; (* ..g STRPTR            *)
  CONST aStringAttachedList         * = 80420FD2H; (* i.. Object *          *)
  CONST aStringBufferPos            * = 80428B6CH; (* .sg LONG              *)
  CONST aStringContents             * = 80428FFDH; (* isg STRPTR            *)
  CONST aStringDisplayPos           * = 8042CCBFH; (* .sg LONG              *)
  CONST aStringFormat               * = 80427484H; (* i.g LONG              *)
  CONST aStringInteger              * = 80426E8AH; (* isg ULONG             *)
  CONST aStringMaxLen               * = 80424984H; (* i.. LONG              *)
  CONST aStringReject               * = 8042179CH; (* isg STRPTR            *)
  CONST aStringSecret               * = 80428769H; (* i.g BOOL              *)

  CONST vStringFormatLeft           * = 0;
  CONST vStringFormatCenter         * = 1;
  CONST vStringFormatRight          * = 2;


(****************************************************************************)
(** Prop.mui 6.73 (26.10.93)                                               **)
(****************************************************************************)

  cProp * = "Prop.mui";

(* Attributes *)

  CONST aPropEntries                * = 8042FBDBH; (* isg LONG              *)
  CONST aPropFirst                  * = 8042D4B2H; (* isg LONG              *)
  CONST aPropHoriz                  * = 8042F4F3H; (* i.g BOOL              *)
  CONST aPropVisible                * = 8042FEA6H; (* isg LONG              *)



(****************************************************************************)
(** Gauge.mui 6.56 (26.10.93)                                              **)
(****************************************************************************)

  cGauge * = "Gauge.mui";

(* Attributes *)

  CONST aGaugeCurrent               * = 8042F0DDH; (* isg LONG              *)
  CONST aGaugeDivide                * = 8042D8DFH; (* isg BOOL              *)
  CONST aGaugeHoriz                 * = 804232DDH; (* i.. BOOL              *)
  CONST aGaugeMax                   * = 8042BCDBH; (* isg LONG              *)



(****************************************************************************)
(** Scale.mui 6.50 (26.10.93)                                              **)
(****************************************************************************)

  cScale * = "Scale.mui";

(* Attributes *)

  CONST aScaleHoriz                 * = 8042919AH; (* isg BOOL              *)



(****************************************************************************)
(** Boopsi.mui 6.52 (26.10.93)                                             **)
(****************************************************************************)

  cBoopsi * = "Boopsi.mui";

(* Attributes *)

  CONST aBoopsiClass                * = 80426999H; (* isg struct IClass *   *)
  CONST aBoopsiClassID              * = 8042BFA3H; (* isg char *            *)
  CONST aBoopsiMaxHeight            * = 8042757FH; (* isg ULONG             *)
  CONST aBoopsiMaxWidth             * = 8042BCB1H; (* isg ULONG             *)
  CONST aBoopsiMinHeight            * = 80422C93H; (* isg ULONG             *)
  CONST aBoopsiMinWidth             * = 80428FB2H; (* isg ULONG             *)
  CONST aBoopsiObject               * = 80420178H; (* ..g Object *          *)
  CONST aBoopsiRemember             * = 8042F4BDH; (* i.. ULONG             *)
  CONST aBoopsiTagDrawInfo          * = 8042BAE7H; (* isg ULONG             *)
  CONST aBoopsiTagScreen            * = 8042BC71H; (* isg ULONG             *)
  CONST aBoopsiTagWindow            * = 8042E11DH; (* isg ULONG             *)



(****************************************************************************)
(** Colorfield.mui 6.13 (26.10.93)                                         **)
(****************************************************************************)

  cColorfield * = "Colorfield.mui";

(* Attributes *)

  CONST aColorfieldBlue             * = 8042D3B0H; (* isg ULONG             *)
  CONST aColorfieldGreen            * = 80424466H; (* isg ULONG             *)
  CONST aColorfieldRed              * = 804279F6H; (* isg ULONG             *)
  CONST aColorfieldRGB              * = 8042677AH; (* isg ULONG *           *)



(****************************************************************************)
(** List.mui 6.111 (27.10.93)                                              **)
(****************************************************************************)

  cList * = "List.mui";

(* Methods *)

  CONST mListClear                 * = 8042AD89H;
  CONST mListExchange              * = 8042468CH;
  CONST mListGetEntry              * = 804280ECH;
  CONST mListInsert                * = 80426C87H;
  CONST mListJump                  * = 8042BAABH;
  CONST mListNextSelected          * = 80425F17H;
  CONST mListRedraw                * = 80427993H;
  CONST mListRemove                * = 8042647EH;
  CONST mListSelect                * = 804252D8H;
  CONST mListSort                  * = 80422275H;

(* Attributes *)

  CONST aListActive                 * = 8042391CH; (* isg LONG              *)
  CONST aListAdjustHeight           * = 8042850DH; (* i.. BOOL              *)
  CONST aListAdjustWidth            * = 8042354AH; (* i.. BOOL              *)
  CONST aListCompareHook            * = 80425C14H; (* i.. struct Hook *     *)
  CONST aListConstructHook          * = 8042894FH; (* i.. struct Hook *     *)
  CONST aListDestructHook           * = 804297CEH; (* i.. struct Hook *     *)
  CONST aListDisplayHook            * = 8042B4D5H; (* i.. struct Hook *     *)
  CONST aListEntries                * = 80421654H; (* ..g LONG              *)
  CONST aListFirst                  * = 804238D4H; (* ..g LONG              *)
  CONST aListFormat                 * = 80423C0AH; (* isg STRPTR            *)
  CONST aListMultiTestHook          * = 8042C2C6H; (* i.. struct Hook *     *)
  CONST aListQuiet                  * = 8042D8C7H; (* .s. BOOL              *)
  CONST aListVisible                * = 8042191FH; (* ..g LONG              *)

  CONST vListActiveOff              * = -1;
  CONST vListActiveTop              * = -2;
  CONST vListActiveBottom           * = -3;
  CONST vListActiveUp               * = -4;
  CONST vListActiveDown             * = -5;
  CONST vListActivePageUp           * = -6;
  CONST vListActivePageDown         * = -7;
  CONST vListConstructHookString    * = -1;
  CONST vListDestructHookString     * = -1;


(****************************************************************************)
(** Floattext.mui 6.48 (26.10.93)                                          **)
(****************************************************************************)

  cFloattext * = "Floattext.mui";

(* Attributes *)

  CONST aFloattextJustify           * = 8042DC03H; (* isg BOOL              *)
  CONST aFloattextSkipChars         * = 80425C7DH; (* is. STRPTR            *)
  CONST aFloattextTabSize           * = 80427D17H; (* is. LONG              *)
  CONST aFloattextText              * = 8042D16AH; (* isg STRPTR            *)



(****************************************************************************)
(** Volumelist.mui 6.50 (26.10.93)                                         **)
(****************************************************************************)

  cVolumelist * = "Volumelist.mui";


(****************************************************************************)
(** Scrmodelist.mui 6.15 (26.10.93)                                        **)
(****************************************************************************)

  cScrmodelist * = "Scrmodelist.mui";

(* Attributes *)




(****************************************************************************)
(** Dirlist.mui 6.50 (27.10.93)                                            **)
(****************************************************************************)

  cDirlist * = "Dirlist.mui";

(* Methods *)

  CONST mDirlistReRead             * = 80422D71H;

(* Attributes *)

  CONST aDirlistAcceptPattern       * = 8042760AH; (* is. STRPTR            *)
  CONST aDirlistDirectory           * = 8042EA41H; (* is. STRPTR            *)
  CONST aDirlistDrawersOnly         * = 8042B379H; (* is. BOOL              *)
  CONST aDirlistFilesOnly           * = 8042896AH; (* is. BOOL              *)
  CONST aDirlistFilterDrawers       * = 80424AD2H; (* is. BOOL              *)
  CONST aDirlistFilterHook          * = 8042AE19H; (* is. struct Hook *     *)
  CONST aDirlistMultiSelDirs        * = 80428653H; (* is. BOOL              *)
  CONST aDirlistNumBytes            * = 80429E26H; (* ..g LONG              *)
  CONST aDirlistNumDrawers          * = 80429CB8H; (* ..g LONG              *)
  CONST aDirlistNumFiles            * = 8042A6F0H; (* ..g LONG              *)
  CONST aDirlistPath                * = 80426176H; (* ..g STRPTR            *)
  CONST aDirlistRejectIcons         * = 80424808H; (* is. BOOL              *)
  CONST aDirlistRejectPattern       * = 804259C7H; (* is. STRPTR            *)
  CONST aDirlistSortDirs            * = 8042BBB9H; (* is. LONG              *)
  CONST aDirlistSortHighLow         * = 80421896H; (* is. BOOL              *)
  CONST aDirlistSortType            * = 804228BCH; (* is. LONG              *)
  CONST aDirlistStatus              * = 804240DEH; (* ..g LONG              *)

  CONST vDirlistSortDirsFirst       * = 0;
  CONST vDirlistSortDirsLast        * = 1;
  CONST vDirlistSortDirsMix         * = 2;
  CONST vDirlistSortTypeName        * = 0;
  CONST vDirlistSortTypeDate        * = 1;
  CONST vDirlistSortTypeSize        * = 2;
  CONST vDirlistStatusInvalid       * = 0;
  CONST vDirlistStatusReading       * = 1;
  CONST vDirlistStatusValid         * = 2;


(****************************************************************************)
(** Group.mui 6.168 (26.10.93)                                             **)
(****************************************************************************)

  cGroup * = "Group.mui";

(* Methods *)


(* Attributes *)

  CONST aGroupActivePage            * = 80424199H; (* isg LONG              *)
  CONST aGroupChild                 * = 804226E6H; (* i.. Object *          *)
  CONST aGroupColumns               * = 8042F416H; (* is. LONG              *)
  CONST aGroupHoriz                 * = 8042536BH; (* i.. BOOL              *)
  CONST aGroupHorizSpacing          * = 8042C651H; (* is. LONG              *)
  CONST aGroupPageMode              * = 80421A5FH; (* is. BOOL              *)
  CONST aGroupRows                  * = 8042B68FH; (* is. LONG              *)
  CONST aGroupSameHeight            * = 8042037EH; (* i.. BOOL              *)
  CONST aGroupSameSize              * = 80420860H; (* i.. BOOL              *)
  CONST aGroupSameWidth             * = 8042B3ECH; (* i.. BOOL              *)
  CONST aGroupSpacing               * = 8042866DH; (* is. LONG              *)
  CONST aGroupVertSpacing           * = 8042E1BFH; (* is. LONG              *)



(****************************************************************************)
(** Virtgroup.mui 6.42 (26.10.93)                                          **)
(****************************************************************************)

  cVirtgroup * = "Virtgroup.mui";

(* Methods *)


(* Attributes *)

  CONST aVirtgroupHeight            * = 80423038H; (* ..g LONG              *)
  CONST aVirtgroupLeft              * = 80429371H; (* isg LONG              *)
  CONST aVirtgroupTop               * = 80425200H; (* isg LONG              *)
  CONST aVirtgroupWidth             * = 80427C49H; (* ..g LONG              *)



(****************************************************************************)
(** Scrollgroup.mui 6.48 (26.10.93)                                        **)
(****************************************************************************)

  cScrollgroup * = "Scrollgroup.mui";

(* Attributes *)

  CONST aScrollgroupContents        * = 80421261H; (* i.. Object *          *)



(****************************************************************************)
(** Scrollbar.mui 6.52 (26.10.93)                                          **)
(****************************************************************************)

  cScrollbar * = "Scrollbar.mui";


(****************************************************************************)
(** Listview.mui 6.55 (26.10.93)                                           **)
(****************************************************************************)

  cListview * = "Listview.mui";

(* Attributes *)

  CONST aListviewDoubleClick        * = 80424635H; (* i.g BOOL              *)
  CONST aListviewInput              * = 8042682DH; (* i.. BOOL              *)
  CONST aListviewList               * = 8042BCCEH; (* i.. Object *          *)
  CONST aListviewMultiSelect        * = 80427E08H; (* i.. BOOL              *)
  CONST aListviewSelectChange       * = 8042178FH; (* ..g BOOL              *)



(****************************************************************************)
(** Radio.mui 6.45 (26.10.93)                                              **)
(****************************************************************************)

  cRadio * = "Radio.mui";

(* Attributes *)

  CONST aRadioActive                * = 80429B41H; (* isg LONG              *)
  CONST aRadioEntries               * = 8042B6A1H; (* i.. STRPTR *          *)



(****************************************************************************)
(** Cycle.mui 6.68 (27.10.93)                                              **)
(****************************************************************************)

  cCycle * = "Cycle.mui";

(* Attributes *)

  CONST aCycleActive                * = 80421788H; (* isg LONG              *)
  CONST aCycleEntries               * = 80420629H; (* i.. STRPTR *          *)

  CONST vCycleActiveNext            * = -1;
  CONST vCycleActivePrev            * = -2;


(****************************************************************************)
(** Slider.mui 6.50 (26.10.93)                                             **)
(****************************************************************************)

  cSlider * = "Slider.mui";

(* Attributes *)

  CONST aSliderLevel                * = 8042AE3AH; (* isg LONG              *)
  CONST aSliderMax                  * = 8042D78AH; (* i.. LONG              *)
  CONST aSliderMin                  * = 8042E404H; (* i.. LONG              *)
  CONST aSliderQuiet                * = 80420B26H; (* i.. BOOL              *)



(****************************************************************************)
(** Coloradjust.mui 6.30 (26.10.93)                                        **)
(****************************************************************************)

  cColoradjust * = "Coloradjust.mui";

(* Attributes *)

  CONST aColoradjustBlue            * = 8042B8A3H; (* isg ULONG             *)
  CONST aColoradjustGreen           * = 804285ABH; (* isg ULONG             *)
  CONST aColoradjustModeID          * = 8042EC59H; (* isg ULONG             *)
  CONST aColoradjustRed             * = 80420EAAH; (* isg ULONG             *)
  CONST aColoradjustRGB             * = 8042F899H; (* isg ULONG *           *)



(****************************************************************************)
(** Palette.mui 6.21 (26.10.93)                                            **)
(****************************************************************************)

  cPalette * = "Palette.mui";

(* Attributes *)

  CONST aPaletteEntries             * = 8042A3D8H; (* i.g struct MUI_Palette_Entry * *)
  CONST aPaletteGroupable           * = 80423E67H; (* isg BOOL              *)
  CONST aPaletteNames               * = 8042C3A2H; (* isg char **           *)


(***************************************************************************
** Method Parameter Structures
***************************************************************************)

TYPE
  pNotify * = STRUCT( msg * : Intuition.Msg );
                trigAttr * : LONGINT;
                trigVal  * : LONGINT;
                destObj  * : Object;
              END;

  pCallHook * = STRUCT( msg * : Intuition.Msg );
                  hook * : Utility.HookPtr;
                  (* following hookparams *)
                END;

  pSet      * = STRUCT( msg * : Intuition.Msg );
                  attr * : LONGINT;
                  val  * : LONGINT;
                END;

  pSetAsString * = STRUCT( msg * : Intuition.Msg );
                     attr   * : LONGINT;
                     format * : Exec.STRPTR;
                     val    * : LONGINT;
                   END;


  pApplicationInput * = STRUCT( msg * : Intuition.Msg );
                          signal * : POINTER TO LONGSET;
                        END;

  pApplicationReturnID * = STRUCT( msg * : Intuition.Msg );
                             retid * : LONGINT;
                           END;

  pApplicationSave * = STRUCT( msg * : Intuition.Msg );
                         name * : Exec.STRPTR;
                       END;

  pApplicationLoad * = STRUCT( msg * : Intuition.Msg );
                         name * : Exec.STRPTR;
                       END;

  pApplicationSetMenuCheck * = STRUCT( msg * : Intuition.Msg );
                      menuID * : LONGINT;
                      set    * : LONGINT;
                    END;

  pApplicationGetMenuCheck * = STRUCT( msg * : Intuition.Msg );
                      menuID * : LONGINT;
                    END;

  pApplicationSetMenuState * = STRUCT( msg * : Intuition.Msg );
                      menuID * : LONGINT;
                      set    * : LONGINT;
                    END;

  pApplicationGetMenuState * = STRUCT( msg * : Intuition.Msg );
                      menuID * : LONGINT;
                    END;

  pApplicationShowHelp * = STRUCT( msg * : Intuition.Msg );
                             window * : Object;
                             name   * : Exec.STRPTR;
                             node   * : Exec.STRPTR;
                             line   * : LONGINT;
                           END;

  pApplicationPushMethod * = STRUCT( msg * : Intuition.Msg );
                               dest * : Object;
                               (* following Method *)
                             END;

  pWindowSetCycleChain * = STRUCT( msg * : Intuition.Msg );
                             (* following objects *)
                           END;

  pWindowSetMenuCheck * = STRUCT( msg * : Intuition.Msg );
                            menuID * : LONGINT;
                            set    * : LONGINT;
                          END;

  pWindowGetMenuCheck * = STRUCT( msg * : Intuition.Msg );
                            menuID * : LONGINT;
                          END;

  pWindowSetMenuState * = STRUCT( msg * : Intuition.Msg );
                            menuID * : LONGINT;
                            set    * : LONGINT;
                          END;

  pWindowGetMenuState * = STRUCT( msg * : Intuition.Msg );
                            menuID * : LONGINT;
                          END;


  pListInsert * = STRUCT( msg * : Intuition.Msg );
                    entries * : Exec.APTR;
                    count   * : LONGINT;
                    pos     * : LONGINT;
                  END;

  pListRemove * = STRUCT( msg * : Intuition.Msg );
                    pos * : LONGINT;
                  END;

  pListGetEntry * = STRUCT( msg * : Intuition.Msg );
                      pos * : LONGINT;
                      entry * : Exec.APTR
                    END;

  pListSelect * = STRUCT( msg * : Intuition.Msg );
                    pos     * : LONGINT;
                    selType * : LONGINT;
                    state   * : POINTER TO LONGINT;
                  END;

  pListRedraw * = STRUCT( msg * : Intuition.Msg );
                    pos * : LONGINT;
                  END;
  pListJump * = STRUCT( msg * : Intuition.Msg );
                    pos * : LONGINT;
                  END;

  pListExchange * = STRUCT( msg * : Intuition.Msg );
                      pos1 * : LONGINT;
                      pos2 * : LONGINT;
                    END;



(***************************************************************************
** Functions in muimaster.library
***************************************************************************)

VAR
  base * : Exec.LibraryPtr;

PROCEDURE NewObjectA           * {base,-30}( class{8}      : ARRAY OF CHAR;
                                             tags{9}       : ARRAY OF Utility.TagItem): Object;

PROCEDURE NewObject            * {base,-30}( class{8}      : ARRAY OF CHAR;
                                             tags{9}..     : Utility.Tag): Object;

PROCEDURE DisposeObject        * {base,-36}( obj{8}        : Object);


PROCEDURE RequestA             * {base,-42}( app{0}        : Object;
                                             win{1}        : Object;
                                             flags{2}      : LONGINT;
                                             title{8}      : ARRAY OF CHAR;
                                             gadgets{9}    : ARRAY OF CHAR;
                                             format{10}    : ARRAY OF CHAR;
                                             params{11}    : ARRAY OF Utility.TagItem) : LONGINT;

PROCEDURE Request              * {base,-42}( app{0}        : Object;
                                             win{1}        : Object;
                                             flags{2}      : LONGINT;
                                             title{8}      : ARRAY OF CHAR;
                                             gadgets{9}    : ARRAY OF CHAR;
                                             format{10}    : ARRAY OF CHAR;
                                             params{11}..  : Utility.Tag) : LONGINT;

PROCEDURE AllocAslRequest      * {base,-48}( typ{0}  : LONGINT;
                                             tags{8} : ARRAY OF Utility.TagItem) : ASL.ASLRequesterPtr;

PROCEDURE AllocAslRequestTags  * {base,-48}( typ{0}    : LONGINT;
                                             tags{8}.. : Utility.Tag) : ASL.ASLRequesterPtr;

PROCEDURE AslRequest           * {base,-54}( req{8}  : ASL.ASLRequesterPtr;
                                             tags{9} : ARRAY OF Utility.TagItem) : BOOLEAN;

PROCEDURE AslRequestTags       * {base,-54}( req{8}    : ASL.ASLRequesterPtr;
                                             tags{9}.. : Utility.Tag) : BOOLEAN;

PROCEDURE FreeAslRequest       * {base,-60}( req{8}  : ASL.ASLRequesterPtr );

PROCEDURE Error                * {base,-66}() : LONGINT;



PROCEDURE DoMethodA * ( obj{10}, msg{9}: Intuition.Msg ): LONGINT;

BEGIN  (* $EntryExitCode- *)
  SYSTEM.INLINE(  0206AH, 0FFFCH,    (*  movea.l -4(a2),a0    *)
                  02F28H, 00008H,    (*  move.l  8(a0),-(a7)  *)
                  04E75H);           (*  rts                  *)
END DoMethodA;

PROCEDURE DoMethod * {"Mui.DoMethodA"} ( obj{10}: Object; msg{9}..: Exec.APTR );
PROCEDURE DOMethod * {"Mui.DoMethodA"} ( obj{10}: Object; msg{9}..: Exec.APTR ) : LONGINT;

BEGIN
  base := Exec.OpenLibrary( LibName, Version);
  IF base=NIL THEN
    IF Intuition.DisplayAlert(0,"\x00\x64\x14missing muimaster.library\o\o",50) THEN END;
    HALT(0)
  END;
CLOSE
  IF base#NIL THEN Exec.CloseLibrary(base) END;
END Mui.
